@@ -1,6 +1,10 @@
 #ifndef GNOME_H
 #define GNOME_H
 
+#ifdef NEED_GNOMESUPPORT_H
+#include "gnomesupport.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <gdk_imlib.h>
 #include "libgnome/libgnome.h"
