@@ -2,8 +2,11 @@
  * Copyright 1997 Paolo Molaro 
  *  This is LGPL'ed code.
  */
+
+#include <config.h>
+
 #include <gtk/gtk.h>
-#include "libgnome.h"
+#include "libgnomeP.h"
 #include "gnome-mime.h"
 #include <string.h>
 #include <ctype.h>
