@@ -1,3 +1,5 @@
+/* Note: Keep this file in sync with libgnomeP.h.  */
+
 #ifndef LIBGNOME_H
 #define LIBGNOME_H
 
@@ -6,6 +8,7 @@
 #include "libgnome/gnome-dentry.h"
 #include "libgnome/gnome-dl.h"
 #include "libgnome/gnome-exec.h"
+#include "libgnome/gnome-help.h"
 #include "libgnome/gnome-hook.h"
 #include "libgnome/gnome-i18n.h"
 #include "libgnome/gnome-parse.h"
