@@ -17,7 +17,11 @@ typedef enum {
   GNOME_APP_UI_SUBTREE,
   GNOME_APP_UI_SEPARATOR,
   GNOME_APP_UI_HELP,
-  GNOME_APP_UI_JUSTIFY_RIGHT /* this should right justify all the following entries */
+  GNOME_APP_UI_JUSTIFY_RIGHT, /* this should right justify all the following entries */
+  GNOME_APP_UI_BUILDER_DATA   /* specifies the builder data for the following entries, see code for further info */
+  /* one should be careful when using gnome_app_create_*_[custom|interp|with_data]() functions
+     with GnomeUIInfo arrays containing GNOME_APP_UI_BUILDER_DATA items since their GnomeUIBuilderData
+     structures completely override the ones generated or supplied by the above functions. */
 } GnomeUIInfoType;
 
 typedef enum {
@@ -45,7 +49,9 @@ struct _GnomeUIInfo {
      call when activated.
      
      For a help item, specifies the help node to load
-     (or NULL for main prog's name) */
+     (or NULL for main prog's name)
+
+     For builder data, point to the GnomeUIBuilderData structure for the following items */
   gpointer moreinfo;
 
   /* Value for pass to gtk_signal_connect() */
@@ -79,6 +85,11 @@ typedef struct _GnomeUIInfo GnomeUIInfo;
 #define GNOMEUIINFO_SEPARATOR {GNOME_APP_UI_SEPARATOR, NULL, NULL, NULL, \
                                NULL, NULL, (GnomeUIPixmapType)0, NULL, 0, \
                                (GdkModifierType)0, NULL}
+#define GNOMEUIINFO_JUSTIFY_RIGHT   {GNOME_APP_UI_JUSTIFY_RIGHT, \
+                                     NULL, NULL, NULL, NULL, NULL, \
+                                     (GnomeUIPixmapType)0, NULL, 0, \
+                                     (GdkModifierType)0, NULL}
+
 #define GNOMEUIINFO_ITEM(label, tip, cb, xpm) \
                               {GNOME_APP_UI_ITEM, label, tip, cb, \
 			       NULL, NULL, GNOME_APP_PIXMAP_DATA, xpm, \
@@ -87,6 +98,10 @@ typedef struct _GnomeUIInfo GnomeUIInfo;
                               {GNOME_APP_UI_ITEM, label, tip, cb, \
 			       NULL, NULL, GNOME_APP_PIXMAP_STOCK, xpm, \
 			       0, (GdkModifierType)0, NULL}
+#define GNOMEUIINFO_ITEM_NONE(label, tip, cb) \
+                              {GNOME_APP_UI_ITEM, label, tip, cb, \
+			       NULL, NULL, GNOME_APP_PIXMAP_NONE, NULL, \
+			       0, (GdkModifierType)0, NULL}
 #define GNOMEUIINFO_ITEM_DATA(label, tip, cb, data, xpm) \
                               {GNOME_APP_UI_ITEM, label, tip, cb, \
 			       data, NULL, GNOME_APP_PIXMAP_DATA, xpm, \
@@ -123,11 +138,11 @@ typedef struct _GnomeUIInfo GnomeUIInfo;
 
 /* Functions */
     
-typedef struct _GnomeUIBuilderData *GnomeUIBuilderData;
+typedef struct _GnomeUIBuilderData GnomeUIBuilderData;
 typedef void (*GnomeUISignalConnectFunc)(GnomeApp *app,
 					 GnomeUIInfo *info_item,
 					 gchar *signal_name,
-					 GnomeUIBuilderData uidata);
+					 GnomeUIBuilderData *uidata);
 #define GNOME_UISIGFUNC(x) ((void *)x)
 struct _GnomeUIBuilderData {
   GnomeUISignalConnectFunc connect_func;
@@ -149,7 +164,7 @@ void gnome_app_create_menus_with_data   (GnomeApp *app,
 				         gpointer data);
 void gnome_app_create_menus_custom      (GnomeApp *app,
 					 GnomeUIInfo *menuinfo,
-					 GnomeUIBuilderData uibdata);
+					 GnomeUIBuilderData *uibdata);
 void gnome_app_create_toolbar           (GnomeApp *app,
 			                 GnomeUIInfo *toolbarinfo);
 void gnome_app_create_toolbar_interp    (GnomeApp *app,
@@ -162,7 +177,7 @@ void gnome_app_create_toolbar_with_data (GnomeApp *app,
 				         gpointer data);
 void gnome_app_create_toolbar_custom    (GnomeApp *app,
 					 GnomeUIInfo *tbinfo,
-					 GnomeUIBuilderData uibdata);
+					 GnomeUIBuilderData *uibdata);
 GtkWidget *gnome_app_find_menu_pos      (GtkWidget *parent,
 					 gchar *path,
 					 gint *pos);
@@ -172,7 +187,7 @@ void gnome_app_remove_menus             (GnomeApp *app,
 void gnome_app_insert_menus_custom      (GnomeApp *app,
 					 gchar *path,
 					 GnomeUIInfo *menuinfo,
-					 GnomeUIBuilderData uibdata);
+					 GnomeUIBuilderData *uibdata);
 void gnome_app_insert_menus             (GnomeApp *app,
 					 gchar *path,
 					 GnomeUIInfo *menuinfo);
