@@ -21,8 +21,6 @@
 #ifndef __GNOME_STOCK_H__
 #define __GNOME_STOCK_H__
 
-
-
 #include <libgnome/gnome-defs.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkpixmap.h>
@@ -32,6 +30,10 @@
 /* #include <gdk_imlib.h> */
 
 
+/* Wether or not the new GnomeStock widget should be used */
+#define USE_NEW_GNOME_STOCK 1
+
+
 /* A short description:
  *
  *  These functions provide an applications programmer with default
@@ -255,6 +257,7 @@ union _GnomeStockPixmapEntry {
 
 
 
+#if !USE_NEW_GNOME_STOCK
 /* the GnomeStockPixmapWidget */
 
 #define GNOME_STOCK_PIXMAP_WIDGET(obj)         GTK_CHECK_CAST(obj, gnome_stock_pixmap_widget_get_type(), GnomeStockPixmapWidget)
@@ -282,6 +285,41 @@ struct _GnomeStockPixmapWidgetClass {
 guint gnome_stock_pixmap_widget_get_type(void);
 GtkWidget *gnome_stock_pixmap_widget_new(GtkWidget *window, const char *icon);
 
+#else /* USE_NEW_GNOME_STOCK */
+
+#define GNOME_STOCK_PIXMAP_WIDGET GNOME_STOCK
+#define GNOME_IS_STOCK_PIXMAP_WIDGET GNOME_IS_STOCK
+
+GtkWidget *gnome_stock_pixmap_widget_new(GtkWidget *window, const char *icon);
+
+#endif /* USE_NEW_GNOME_STOCK */
+
+
+/* The new GnomeStock widget */
+
+
+#define GNOME_STOCK(obj)         GTK_CHECK_CAST(obj, gnome_stock_get_type(), GnomeStock)
+#define GNOME_STOCK_CLASS(klass) GTK_CHECK_CAST_CLASS(obj, gnome_stock_get_type(), GnomeStock)
+#define GNOME_IS_STOCK(obj)      GTK_CHECK_TYPE(obj, gnome_stock_get_type())
+
+typedef struct _GnomeStock       GnomeStock;
+typedef struct _GnomeStockClass  GnomeStockClass;
+
+struct _GnomeStock {
+	GnomePixmap pixmap;
+	GnomePixmap *regular, *disabled, *focused; /* pixmap cache */
+	GnomePixmap *current;
+	char *icon;
+};
+
+struct _GnomeStockClass {
+	GnomePixmapClass pixmap_class;
+};
+
+guint         gnome_stock_get_type(void);
+GtkWidget    *gnome_stock_new(void);
+GtkWidget    *gnome_stock_new_with_icon(const char *icon);
+gboolean      gnome_stock_set_icon(GnomeStock *stock, const char *icon);
 
 
 /* the utility functions */
@@ -298,13 +336,18 @@ GnomePixmap           *gnome_stock_pixmap          (GtkWidget *window,
                                                     const char *subtype);
 #endif
 
-/* just fetch a GnomeStockPixmapWidget */
+/* just fetch a GnomeStock(PixmapWidget) */
 GtkWidget             *gnome_stock_pixmap_widget   (GtkWidget *window,
                                                     const char *icon);
 
 /* change the icon/look of a GnomeStockPixmapWidget */
+#if USE_NEW_GNOME_STOCK
+void gnome_stock_pixmap_widget_set_icon(GnomeStock *widget,
+					const char *icon);
+#else
 void gnome_stock_pixmap_widget_set_icon(GnomeStockPixmapWidget *widget,
 					const char *icon);
+#endif
 
 /* register a pixmap. returns non-zero, if successful */
 gint                   gnome_stock_pixmap_register (const char *icon,
