@@ -124,6 +124,7 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
   int attr;
   uint32 c;
   struct vt_line *bl;
+  int noclear;			/* clear before writing text? */
 
   d(printf("updating line %d: ", line));
   d(fwrite(l->data, l->width, 1, stdout));
@@ -142,10 +143,11 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
   runbuffer = alloca(vx->vt.width * sizeof(char));
 
   bl = (struct vt_line *)vt_list_index(&vx->vt.lines_back, line);
-  if (bl->width != l->width) {
-    /* this should *always* be true */
-    printf("ASSERTION FAILED: line width mismatch %d != %d\n", bl->width, l->width);
-  }
+
+  /* some sanity checks */
+  g_return_if_fail (bl != NULL);
+  g_return_if_fail (runbuffer != NULL);
+  g_return_if_fail (bl->width == l->width);
 
   /* work out the minimum range of change */
   if (!always) {
@@ -161,25 +163,23 @@ static void vt_line_update(struct _vtx *vx, struct vt_line *l, int line, int alw
 	break;
       end--;
     }
-    
-    if (end<l->width)
-      end++;
-    
-    /* copy changed section of line to destination line */
-    for(i=start;i<end;i++) {
-      bl->data[i]=l->data[i];
-    }
-    bl->line = line;
-  } else {
+  }  /* else, update everything */
 
-    /* always update everything, so always update the whole 'offscreen' buffer */
-    for(i=start;i<end;i++) {
-      bl->data[i]=l->data[i];
+  /* see if on-screen is all background ... */
+  vx->back_match=1;
+  for(i=start;i<end;i++) {
+    if ((bl->data[i] & ~VTATTR_CHANGED) != (vx->vt.attr&~VTATTR_CHANGED)) {
+      vx->back_match=0;
+      break;
     }
-    bl->line = line;
-
   }
 
+  /* copy changed section of line to destination line */
+  for(i=start;i<end;i++) {
+    bl->data[i]=l->data[i];
+  }
+  bl->line = line;
+
   d(printf("actually (%d-%d)?\n", start, end));
 
   run=0;
@@ -601,7 +601,7 @@ void vt_update(struct _vtx *vx, int update_state)
     while (nb) {
       printf("%d: ", wb->line);
       for (i=0;i<wb->width;i++) {
-	(printf("%c", (wb->data[i]&0xffff)>=32?(wb->data[i]&0xffff):' '));
+	(printf("%c", (wb->data[i]&0xffff))); /*>=32?(wb->data[i]&0xffff):' '));*/
       }
       (printf("\n"));
       wb=nb;
@@ -944,7 +944,8 @@ void vt_draw_selection_part(struct _vtx *vx, int sx, int sy, int ex, int ey)
   d(printf("selecting from (%d,%d) to (%d,%d)\n", sx, sy-vx->vt.scrollbackoffset, ex, ey-vx->vt.scrollbackoffset));
   while ((line<=ey) && (l->next) && ((line-vx->vt.scrollbackoffset)<vx->vt.height)) {
     d(printf("line %d = %p ->next = %p\n", line, l, l->next));
-    vt_line_update(vx, l, line-vx->vt.scrollbackoffset, 1, 0, l->width);
+    if ((line-vx->vt.scrollbackoffset)>=0)
+      vt_line_update(vx, l, line-vx->vt.scrollbackoffset, 1, 0, l->width);
     line++;
     if (line==0) {
       l = (struct vt_line *)vt_list_index(&vx->vt.lines, 0);
@@ -990,13 +991,14 @@ void vt_draw_cursor(struct _vtx *vx, int state)
   if (vx->vt.scrollbackoffset == 0) {
     attr = vx->vt.this->data[vx->vt.cursorx];
     c = attr & 0xff;
-    if (c==9)			/* remap tab */
+    if (c==9 || c==0)			/* remap tab */
       c=' ';
     if (state) {			/* must swap fore/background colour */
       attr = (((attr & VTATTR_FORECOLOURM) >> VTATTR_FORECOLOURB) << VTATTR_BACKCOLOURB)
 	| (((attr & VTATTR_BACKCOLOURM) >> VTATTR_BACKCOLOURB) << VTATTR_FORECOLOURB)
       | ( attr & ~(VTATTR_FORECOLOURM|VTATTR_BACKCOLOURM));
     }
+    vx->back_match=0;		/* forces re-draw? */
     vt_draw_text(vx->user_data, vx->vt.cursorx, vx->vt.cursory, &c, 1, attr);
   }
 }
