@@ -26,6 +26,7 @@
 
 #include <errno.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "zvtterm.h"
 
@@ -154,7 +155,8 @@ zvt_term_init (ZvtTerm *term)
   term->cursor_blink_state = 0;
   term->blink_enabled = 1;
   term->ic = NULL;
-  
+  term->in_expose = 0;
+
   /* input handler */
   term->input_id = -1;
 
@@ -255,7 +257,7 @@ zvt_term_set_color_scheme (ZvtTerm *term, gushort *red, gushort *grn, gushort *b
   nallocated = 0;
   gdk_color_context_get_pixels (term->color_ctx, red, grn, blu,
 				18, term->colors, &nallocated);
-  c.pixel = term->colors [18];
+  c.pixel = term->colors [17];
   gdk_window_set_background (GTK_WIDGET (term)->window, &c);
 }
 
@@ -505,11 +507,13 @@ zvt_term_expose (GtkWidget      *widget,
   d(printf("exposed!\n"));
 
   /* FIXME: may update 1 more line/char than needed */
+  term->in_expose = 1;
   vt_update_rect(term->vx,
 		 event->area.x/term->charwidth,
 		 event->area.y/term->charheight,
 		 (event->area.x+event->area.width)/term->charwidth+1,
 		 (event->area.y+event->area.height)/term->charheight+1);
+  term->in_expose = 0;
 
   return FALSE;
 }
@@ -1101,8 +1105,12 @@ int zvt_term_closepty(ZvtTerm *term)
 static void
 zvt_term_scroll (ZvtTerm *term, int n)
 {
+  gfloat new_value;
+  new_value = term->adjustment->value + (n * term->adjustment->page_size);
   gtk_adjustment_set_value (term->adjustment,
-			    term->adjustment->value + (n * term->adjustment->page_size));
+							n > 0 ? MIN(new_value, term->adjustment->upper
+										 - term->adjustment->page_size)
+							       : MAX(new_value, term->adjustment->lower));
 }
 
 /*
@@ -1130,6 +1138,9 @@ zvt_term_key_press (GtkWidget *widget, GdkEventKey *event)
   handled = TRUE;
   switch (event->keyval) {
   case GDK_BackSpace:
+    if (event->state & GDK_MOD1_MASK){
+      *p++ = '\033';
+    }
     *p++ = 8;
     break;
   case GDK_KP_Right:
@@ -1153,6 +1164,9 @@ zvt_term_key_press (GtkWidget *widget, GdkEventKey *event)
     p+=sprintf (p, "\033[2~");
     break;
   case GDK_Delete:
+    if (event->state & GDK_MOD1_MASK){
+      *p++ = '\033';
+    }
     *p++ = '\177';
     break;
   case GDK_KP_Delete:
@@ -1255,6 +1269,15 @@ zvt_term_key_press (GtkWidget *widget, GdkEventKey *event)
   case GDK_Mode_switch:
   case GDK_Multi_key:
     break;
+  case ' ':
+    /* maps single characters to correct control and alt versions */
+    if (event->state & GDK_CONTROL_MASK)
+      *p++=event->keyval & 0x1f;
+    else if (event->state & GDK_MOD1_MASK)
+      *p++=event->keyval + 0x80; /* this works for space at least */
+    else
+      *p++=event->keyval;
+    break;
   default:
       if (event->length > 0){
 	if (event->state & GDK_MOD1_MASK){
@@ -1263,12 +1286,9 @@ zvt_term_key_press (GtkWidget *widget, GdkEventKey *event)
 	memcpy(p, event->string, event->length*sizeof(char));
 	p += event->length;
       } else {
-        if ((event->keyval == 0x20) && (event->state & GDK_CONTROL_MASK)){
-          *p++ = 0;
-	} else   
-	  handled = FALSE;
+	handled = FALSE;
       }
-      printf ("[%s,%d,%d]\n", event->string, event->length, handled);
+      d(printf ("[%s,%d,%d]\n", event->string, event->length, handled));
   }
   if (handled && p>buffer)
     vt_writechild(&vx->vt, buffer, (p-buffer));
@@ -1348,17 +1368,12 @@ static void zvt_term_readdata(gpointer data, gint fd, GdkInputCondition conditio
   /* read failed?
       assume pipe cut - just quit */
   if (count<0 && saveerrno!=EAGAIN) {
-    printf("errno = %d, saverrno = %d\n", errno, saveerrno);
-    printf("out of data on read\n");
-
     /* close this fd, just to make sure (removes input handler too) */
     zvt_term_closepty(term);
 
-    /* signal application */
+    /* signal application FIXME: include error/non error code */
     gtk_signal_emit(GTK_OBJECT(term), term_signals[CHILD_DIED]);
 
-    /* FIXME: raise signal to caller ... */
-    /*gtk_exit(1);*/
     return;
   }
 
@@ -1445,16 +1460,24 @@ void vt_draw_text(void *user_data, int col, int row, char *text, int len, int at
   /* for reverse, swap gc's */
   if (attr & VTATTR_REVERSE){
     GdkGC *tmp = fgc;
+    int tmp2 = fore;
 
     fgc = bgc;
     bgc = tmp;
+
+    fore = back;
+    back = tmp2;
   }
 
-  gdk_draw_rectangle(widget->window,
-		     bgc,
-		     1,
-		     col*term->charwidth, row*term->charheight,
-		     len*term->charwidth, term->charheight);
+  /* optimise: dont 'clear' background if in expose, and background colour == window colour */
+  if ((term->in_expose==0 && vx->back_match==0)
+      || back!=17) {
+    gdk_draw_rectangle(widget->window,
+		       bgc,
+		       1,
+		       col*term->charwidth, row*term->charheight,
+		       len*term->charwidth, term->charheight);
+  }
 
   gdk_draw_text(widget->window,
 		f,
